;-------------------------------------------------------------------------------
; Init clearccase lib functions
;
;   Copyright (C) 2008, 2009 Alesc
;   This program is free software: you can redistribute it and/or modify
;   it under the terms of the GNU General Public License.
;-------------------------------------------------------------------------------

;---------------------------------------
; InitCClib
;
; Arguments: none
;
; Returns:
;   HOT_OK / HOT_ERR
;
; Description:
;   Initializes cc_lib. Must be called before
;   any other cc function is called.
;
; Important globals initialized:
;   CC_PATH      cc home path got from win.reg.
;   CC_EXE       cc tool exe with full path
;---------------------------------------
InitCClib()
{
    global
    ; cleartool should be here
    local ccexe := "bin\cleartool.exe"

    RegRead, CC_PATH, HKEY_LOCAL_MACHINE, Software\Atria\ClearCase\CurrentVersion, Producthome
    if ErrorLevel
    {
        Report("Error", "Can not read CC path from windows registry.(HKEY_LOCAL_MACHINE\Software\Atria\ClearCase\CurrentVersion)")
        return %HOT_ERR%
    }

    CC_EXE = %CC_PATH%\%ccexe%
    IfNotExist, %CC_EXE%
    {
        Report("Error", "Can not find CC tool [" . CC_EXE . "].")
        return %HOT_ERR%
    }

    return %HOT_OK%
}

;-------------------------------------------------------------------------------
; clearcase help functions
;-------------------------------------------------------------------------------

;---------------------------------------
; runCtCmd
;
; Arguments: cmd - arguments to pass to ctExe
;
; Returns:
;   true/false
;
; Description:
;   Runs cleartool with specified arguments.
;   Run and wait to complete.
;---------------------------------------
RunCtCmd(cmd)
{
    global CC_EXE, HOT_OK, HOT_ERR

    file_prefix = RunCtCmd
    DeleteTmpFiles("", file_prefix)
    if (output_file := CreateTmpFile("", file_prefix)) = ""
        return %HOT_ERR%

    cmd = %comspec% /c ""%CC_EXE%" %cmd%" > %output_file% 2>&1
    if RunCmdWait(cmd, "Hide") = HOT_ERR
        return %HOT_ERR%

    FileRead, content, %output_file%
    if ErrorLevel
    {
        Report("Error", output_file . " file not read.")
        return %HOT_ERR%
    }

    if (InStr(content, "cleartool: Error:")) <> 0
    {
        Report("Error", content)
        return %HOT_ERR%
    }

    return %HOT_OK%
}
;---------------------------------------
; runCtCmdWin
;
; Arguments: cmd - arguments to pass to CC_EXE
;
; Returns:
;   true/false
;
; Description:
;   Runs cleartool with specified arguments.
;   Uses run cmd and go. Used for window progs.
;   which remains opened.
;---------------------------------------
RunCtCmdWin(cmd)
{
    global CC_EXE, HOT_OK, HOT_ERR

    file_prefix = RunCtCmdWin
    DeleteTmpFiles("", file_prefix)
    if (output_file := CreateTmpFile("", file_prefix)) = ""
        return %HOT_ERR%

    cmd = %comspec% /c ""%CC_EXE%" %cmd%" > %output_file% 2>&1
    if RunCmd(cmd, "Hide") = HOT_ERR
        return %HOT_ERR%

    ; custom delay because cc returns too quick and writes to output too slow
    if WaitForFileEx(output_file, 500, 9999, 1) = HOT_ERR
        return %HOT_ERR%

    FileRead, content, %output_file%
    if ErrorLevel
    {
        Report("Error", output_file . " file not read.")
        return %HOT_ERR%
    }

    if (InStr(content, "cleartool: Error:")) <> 0
    {
        Report("Error", content)
        return %HOT_ERR%
    }

    return %HOT_OK%
}
